import { CouchDbOptions, CouchDbResponse } from './index';
export declare class CouchDb {
    private host;
    private port;
    private auth;
    private logging;
    defaultDatabase: string;
    constructor(options?: CouchDbOptions.Connection);
    private createQueryString;
    private readonly defaultRequestOptions;
    private request;
    private statusCode;
    getInfo(): PromiseLike<CouchDbResponse.Info>;
    getDatabases(): PromiseLike<string[]>;
    getDatabase(dbName?: string): PromiseLike<CouchDbResponse.DatabaseInfo>;
    getDatabaseRevisionLimit(dbName: string): PromiseLike<{}>;
    checkDatabaseExists(dbName?: string): PromiseLike<boolean>;
    createDatabase(dbName?: string, options?: {
        revisionLimit: number;
    }): Promise<CouchDbResponse.Generic>;
    compactDatabase(dbName: string): PromiseLike<CouchDbResponse.Generic>;
    setDatabaseRevisionLimit(dbName: string, revisionLimit: number): PromiseLike<CouchDbResponse.Generic>;
    deleteDatabase(dbName?: string): PromiseLike<CouchDbResponse.Generic>;
    updateDatabaseSecurity(options: {
        dbName?: string;
        admins: {
            names?: string[];
            roles?: string[];
        };
        members: {
            names?: string[];
            roles?: string[];
        };
    }): PromiseLike<CouchDbResponse.Generic>;
    createUser(options: {
        username: string;
        password: string;
        roles?: string[];
    }): PromiseLike<CouchDbResponse.Create>;
    checkUserExists(username: string): PromiseLike<boolean>;
    getUser(username: string): PromiseLike<CouchDbResponse.Document>;
    updateUserPassword(options: {
        username: string;
        password: string;
    }): Promise<CouchDbResponse.Update>;
    findDocuments(options: {
        dbName?: string;
        findOptions: CouchDbOptions.FindOptions;
    }): PromiseLike<CouchDbResponse.Find>;
    getDocuments(options: {
        dbName?: string;
        options?: CouchDbOptions.FindAllOptions;
    }): PromiseLike<CouchDbResponse.AllDocuments>;
    getDocument(options: {
        docId: string;
        dbName?: string;
    }): PromiseLike<CouchDbResponse.Document>;
    checkDocumentExists(options: {
        dbName?: string;
        docId: string;
    }): PromiseLike<boolean>;
    copyDocument(options: {
        docId: string;
        newDocId: string;
        dbName?: string;
    }): PromiseLike<CouchDbResponse.Create>;
    createDocument(options: {
        doc: any;
        docId?: string;
        dbName?: string;
    }): PromiseLike<{}>;
    upsertDocuments(options: {
        docs: any[];
        dbName?: string;
    }): PromiseLike<CouchDbResponse.Create[]>;
    updateDocument(options: {
        dbName?: string;
        docId: string;
        rev: string;
        updatedDoc: any;
    }): PromiseLike<CouchDbResponse.Create>;
    deleteDocument(options: {
        dbName?: string;
        docId: string;
        rev: string;
    }): PromiseLike<CouchDbResponse.Generic>;
    getUuids(count?: number): PromiseLike<string[]>;
    getDesignDocument(options: {
        dbName?: string;
        docId: string;
        options?: CouchDbOptions.DocumentOptions;
    }): PromiseLike<{}>;
    getDesignDocumentInfo(options: {
        dbName: string;
        docId: string;
    }): PromiseLike<{}>;
    createDesignDocument(options: {
        dbName?: string;
        doc: any;
        docId: string;
    }): PromiseLike<{}>;
    deleteDesignDocument(options: {
        dbName?: string;
        docId: string;
        rev: string;
    }): PromiseLike<{}>;
    getDocumentView(options: {
        dbName?: string;
        docId: string;
        viewName: string;
        options?: CouchDbOptions.DocumentOptions;
    }): PromiseLike<{}>;
    getIndexes(dbName?: string): PromiseLike<{}>;
    createIndex(options: {
        dbName?: string;
        index: any;
        name?: string;
    }): PromiseLike<{}>;
    deleteIndex(options: {
        dbName?: string;
        docId: string;
        indexName: string;
    }): PromiseLike<{}>;
}
